@@ -1,4 +1,7 @@
 from ._version import __version__
-from .utils.mle_experiment import MLExperiment
+from .experiment import MLExperiment
 from .utils.core_experiment import mle_config
 from .utils.core_files_load import load_result_logs
+
+
+__all__ = ["__version__", "MLExperiment", "mle_config", "load_result_logs"]
